@@ -3,14 +3,6 @@ package Fey::SQL::Update;
 use strict;
 use warnings;
 
-use Moose::Policy 'MooseX::Policy::SemiAffordanceAccessor';
-use MooseX::StrictConstructor;
-
-with 'Fey::Role::SQL::HasBindParams',
-     'Fey::Role::SQL::HasWhereClause',
-     'Fey::Role::SQL::HasOrderByClause',
-     'Fey::Role::SQL::HasLimitClause';
-
 use Fey::Exceptions qw( param_error );
 use Fey::Validate
     qw( validate_pos
@@ -24,6 +16,15 @@ use Fey::Literal;
 use overload ();
 use Scalar::Util qw( blessed );
 
+use Moose;
+use MooseX::SemiAffordanceAccessor;
+use MooseX::StrictConstructor;
+
+with 'Fey::Role::SQL::HasBindParams',
+     'Fey::Role::SQL::HasWhereClause',
+     'Fey::Role::SQL::HasOrderByClause',
+     'Fey::Role::SQL::HasLimitClause';
+
 
 {
     my $spec = { type => OBJECT,
@@ -203,6 +204,7 @@ sub bind_params
 }
 
 no Moose;
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
